@@ -75,8 +75,11 @@ def main(args=None, steam_path=None, steam_root=None):
         formatter_class=argparse.RawTextHelpFormatter
     )
     parser.add_argument(
-        "--verbose", "-v", action="store_true",
-        help="Print debug information"
+        "--verbose", "-v", action="count", default=0,
+        help=(
+            "Increase log verbosity. Can be supplied twice for "
+            "maximum verbosity."
+        )
     )
     parser.add_argument(
         "--no-term", action="store_true",
@@ -277,6 +280,13 @@ def main(args=None, steam_path=None, steam_root=None):
         if not proton_app:
             exit_("Proton installation could not be found!")
 
+        if not proton_app.is_proton_ready:
+            exit_(
+                "Proton installation is incomplete. Have you launched a Steam "
+                "app using this Proton version at least once to finish the "
+                "installation?"
+            )
+
         run_command(
             winetricks_path=winetricks_path,
             proton_app=proton_app,
@@ -383,6 +393,8 @@ def main(args=None, steam_path=None, steam_root=None):
             shell=True
         )
 
+    logger.info("Command returned %d", returncode)
+
     sys.exit(returncode)
 
 
