@@ -15,7 +15,7 @@ def home_cwd(home_dir, monkeypatch):
 class TestCLIRun:
     def test_run_executable(
             self, steam_app_factory, default_proton,
-            commands, gui_provider, launch_cli):
+            command_mock, gui_provider, launch_cli):
         """
         Run an EXE file by selecting using the GUI
         """
@@ -27,14 +27,14 @@ class TestCLIRun:
         launch_cli(["test.exe"])
 
         # 'test.exe' was executed
-        command = commands[-1]
+        command = command_mock.commands[-1]
         assert command.args.startswith("wine ")
-        assert command.args.endswith("/test.exe'")
+        assert command.args.endswith("/test.exe")
 
         assert command.env["WINEPREFIX"] == str(steam_app.prefix_path)
 
     def test_run_executable_appid(
-            self, default_proton, steam_app_factory, commands, launch_cli):
+            self, default_proton, steam_app_factory, command_mock, launch_cli):
         """
         Run an EXE file directly for a chosen game
         """
@@ -43,9 +43,9 @@ class TestCLIRun:
         launch_cli(["--appid", "10", "test.exe"])
 
         # 'test.exe' was executed
-        command = commands[-1]
+        command = command_mock.commands[-1]
         assert command.args.startswith("wine ")
-        assert command.args.endswith("/test.exe'")
+        assert command.args.endswith("/test.exe")
 
         assert command.env["WINEPREFIX"] == str(steam_app.prefix_path)
 
@@ -119,11 +119,11 @@ class TestCLIRun:
 
         # CLI flags are passed through to the main CLI entrypoint
         assert cli_args[0:6] == [
-            "--verbose", "--no-runtime", "--no-bwrap",
+            "-v", "--no-runtime", "--no-bwrap",
             "--no-background-wineserver", "--no-term", "-c"
         ]
         assert cli_args[6].startswith("wine ")
-        assert cli_args[6].endswith("test.exe'")
+        assert cli_args[6].endswith("test.exe")
         assert cli_args[7] == "10"
 
         # Steam installation was provided to the main entrypoint
@@ -192,7 +192,9 @@ class TestCLIRun:
 
         assert b"Test appmanifest error" in message
 
-    @pytest.mark.usefixtures("flatpak_sandbox", "default_proton", "commands")
+    @pytest.mark.usefixtures(
+        "flatpak_sandbox", "default_proton", "command_mock"
+    )
     def test_run_filesystem_permission_missing(
             self, launch_cli, steam_library_factory, steam_app_factory,
             caplog):
