@@ -5,7 +5,7 @@ import struct
 import zlib
 from collections import defaultdict
 from pathlib import Path
-from subprocess import run
+from subprocess import run, TimeoutExpired
 
 import pytest
 import vdf
@@ -19,6 +19,7 @@ from protontricks.gui import get_gui_provider
 from protontricks.steam import (APPINFO_STRUCT_HEADER,
                                 APPINFO_V28_STRUCT_SECTION, SteamApp,
                                 get_appid_from_shortcut)
+from protontricks.steam import iter_appinfo_sections
 
 
 @pytest.fixture(scope="function", autouse=True)
@@ -44,13 +45,18 @@ def cleanup():
     logging.getLogger("protontricks").handlers.clear()
 
 
+@pytest.fixture(scope="function", autouse=True)
+def default_caplog(caplog):
+    caplog.set_level(logging.INFO)
+
+
 @pytest.fixture(scope="function")
-def verbose_logging():
+def info_logging():
     """
-    Enable verbose logging to ensure INFO messages are captured by
-    the caplog fixture as well
+    Enable logging to ensure INFO messages are captured by the caplog fixture
+    as well
     """
-    enable_logging(info=True)
+    enable_logging(level=1)
 
 
 @pytest.fixture(scope="function", autouse=True)
@@ -225,7 +231,8 @@ def shortcut_factory(steam_dir, steam_user):
     shortcuts_by_user = defaultdict(list)
 
     def func(
-            install_dir, name, steamid64=None, appid_in_vdf=False, appid=None):
+            install_dir, name, steamid64=None, appid_in_vdf=False, appid=None,
+            icon_path=None):
         if not steamid64:
             steamid64 = steam_user
 
@@ -270,6 +277,9 @@ def shortcut_factory(steam_dir, steam_user):
                     # Lutris, use them as-is
                     entry["appid"] = appid_
 
+            if icon_path:
+                entry["icon"] = icon_path
+
             data["shortcuts"][str(shortcut_id)] = entry
 
         shortcut_path.write_bytes(vdf.binary_dumps(data))
@@ -315,41 +325,61 @@ def steam_config_path(steam_dir):
 
 
 @pytest.fixture(scope="function", autouse=True)
-def appinfo_compat_tool_factory(appinfo_factory):
+def appinfo_compat_tool_factory(appinfo_factory, steam_dir):
     """
     Factory function to add compat tool entries to the appinfo.vdf binary file
     """
-    compat_tools = []
-
     def func(proton_app, compat_tool_name, aliases=None):
+        manifest_appinfo = next(
+            section["appinfo"] for section
+            in iter_appinfo_sections(steam_dir / "appcache" / "appinfo.vdf")
+            if section["appinfo"]["appid"] == 891390
+        )
+
         if not aliases:
             aliases = []
 
         aliases.append(compat_tool_name)
 
-        compat_tools.append({
+        manifest_appinfo["extended"]["compat_tools"][compat_tool_name] = {
             "appid": proton_app.appid,
             "compat_tool_name": compat_tool_name,
-            "aliases": [compat_tool_name] + aliases
-        })
-
-        compat_tool_entries = {}
-
-        for compat_tool in compat_tools:
-            compat_tool_entries[compat_tool["compat_tool_name"]] = {
-                "aliases": ",".join(compat_tool["aliases"]),
-                "appid": compat_tool["appid"]
-            }
+            "aliases": ",".join(aliases)
+        }
 
         # Update the appinfo.vdf with the compat tools that have been
         # added so far.
         appinfo_factory(
             appid=891390,  # Steam Play 2.0 Manifests app ID,
-            appinfo={
-                "extended": {
-                    "compat_tools": compat_tool_entries
-                }
-            }
+            appinfo=manifest_appinfo
+        )
+
+    return func
+
+
+@pytest.fixture(scope="function")
+def appinfo_app_mapping_factory(appinfo_factory, steam_dir):
+    """
+    Factory function to add Steam app specific compat tool app mappings
+    to the appinfo.vdf binary file
+    """
+    def func(steam_app, compat_tool_name):
+        manifest_appinfo = next(
+            section["appinfo"] for section
+            in iter_appinfo_sections(steam_dir / "appcache" / "appinfo.vdf")
+            if section["appinfo"]["appid"] == 891390
+        )
+
+        manifest_appinfo["extended"]["app_mappings"][str(steam_app.appid)] = {
+            "appid": steam_app.appid,
+            "tool": compat_tool_name
+        }
+
+        # Update the appinfo.vdf with the compat tools that have been
+        # added so far.
+        appinfo_factory(
+            appid=891390,  # Steam Play 2.0 Manifests app ID,
+            appinfo=manifest_appinfo
         )
 
     return func
@@ -367,7 +397,8 @@ def appinfo_factory(steam_dir):
             "appinfo": {
                 "appid": 891390,
                 "extended": {
-                    "compat_tools": {}
+                    "compat_tools": {},
+                    "app_mappings": {}
                 }
             }
         }
@@ -508,6 +539,9 @@ def steam_app_factory(steam_dir, steam_config_path):
             prefix_path=str(
                 steamapps_dir / "compatdata" / str(appid)
                 / "pfx"
+            ),
+            icon_path=(
+                steam_dir / "appcache" / "librarycache" / f"{appid}_icon.jpg"
             )
         )
         if required_tool_app:
@@ -747,8 +781,9 @@ def xdg_user_dir_bin(home_dir):
 
 class MockSubprocess:
     def __init__(
-            self, args=None, kwargs=None, mock_stdout=None, check=False,
-            cwd=None, shell=False, env=None, **_):
+            self, args=None, kwargs=None, mock_stdout=None,
+            launcher_alive=True, check=False, cwd=None, shell=False, env=None,
+            **_):
         self.args = args
         self.kwargs = kwargs
         self.check = check
@@ -762,13 +797,26 @@ class MockSubprocess:
         else:
             self.mock_stdout = mock_stdout
 
+        # The state of the mocked 'bwrap-launcher'. This will be set to False
+        # once 'terminate()' is called on the corresponding Popen object to
+        # mock the launcher stopping.
+        self.launcher_alive = launcher_alive
+
         self.env = env
 
-    def wait(self):
-        pass
+    def wait(self, timeout=None):
+        name = self.args[0]
+        if name.endswith("bwrap-launcher"):
+            if self.launcher_alive:
+                raise TimeoutExpired(name, timeout=timeout)
+            else:
+                # Fake launcher crashing
+                self.returncode = 1
 
     def terminate(self):
-        pass
+        name = self.args[0]
+        if name.endswith("bwrap-launcher"):
+            self.launcher_alive = False
 
 
 class MockResult:
@@ -802,13 +850,19 @@ def gui_provider(monkeypatch):
     yield mock_gui_provider
 
 
+class CommandMock:
+    def __init__(self):
+        self.commands = []
+        self.launcher_working = True
+
+
 @pytest.fixture(scope="function")
-def commands(monkeypatch):
+def command_mock(monkeypatch):
     """
-    Fixture containing all the commands called using subprocess during
-    the test run
+    Fixture to mock all subprocess calls. Returns instance containing
+    command history.
     """
-    commands_ = []
+    command_mock = CommandMock()
 
     def mock_subprocess_run(*args, **kwargs):
         try:
@@ -824,17 +878,20 @@ def commands(monkeypatch):
 
         mock_command = MockSubprocess(
             *args,
-            **kwargs
+            **{**kwargs, **{"launcher_alive": command_mock.launcher_working}}
         )
 
-        commands_.append(mock_command)
+        command_mock.commands.append(mock_command)
 
         return MockResult(stdout=b"")
 
     def mock_Popen(*args, **kwargs):
-        mock_command = MockSubprocess(*args, **kwargs)
+        mock_command = MockSubprocess(
+            *args,
+            **{**kwargs, **{"launcher_alive": command_mock.launcher_working}}
+        )
 
-        commands_.append(mock_command)
+        command_mock.commands.append(mock_command)
 
         return mock_command
 
@@ -851,7 +908,7 @@ def commands(monkeypatch):
         mock_subprocess_run
     )
 
-    return commands_
+    return command_mock
 
 
 @pytest.fixture(scope="function")
