@@ -32,6 +32,28 @@ class TestSteamApp:
 
         assert steam_app.name == "Fake game"
         assert steam_app.appid == 10
+        assert not steam_app.icon_path
+
+    def test_steam_app_from_appmanifest_and_steam_path(
+            self, steam_app_factory, steam_dir):
+        """
+        Create a SteamApp from an appmanifest file and Steam path
+        """
+        steam_app = steam_app_factory(name="Fake game", appid=10)
+
+        appmanifest_path = \
+            Path(steam_app.install_path).parent.parent / "appmanifest_10.acf"
+
+        steam_app = SteamApp.from_appmanifest(
+            path=appmanifest_path,
+            steam_lib_paths=[steam_dir / "steam" / "steamapps"],
+            steam_path=steam_dir
+        )
+
+        assert steam_app.name == "Fake game"
+        assert steam_app.appid == 10
+        assert steam_app.icon_path \
+            == steam_dir / "appcache" / "librarycache" / "10_icon.jpg"
 
     @pytest.mark.parametrize(
         "content",
@@ -212,7 +234,7 @@ class TestFindSteamCompatToolApp:
         # version for this game
         assert proton_app.name == "Proton 6.66"
 
-    @pytest.mark.usefixtures("verbose_logging")
+    @pytest.mark.usefixtures("info_logging")
     def test_find_legacy_tool_mapping_global(
             self, steam_dir, steam_config_path, proton_factory,
             steam_app_factory):
@@ -263,9 +285,7 @@ class TestFindSteamCompatToolApp:
         )
         assert proton_app.name == "Proton B"
 
-
-
-    @pytest.mark.usefixtures("steam_deck", "verbose_logging")
+    @pytest.mark.usefixtures("steam_deck", "info_logging")
     def test_find_steam_deck_profile(
             self, steam_app_factory, proton_factory, appinfo_factory,
             default_proton, steam_config_path, steam_dir):
@@ -314,7 +334,7 @@ class TestFindSteamCompatToolApp:
 
         assert proton_app.name == "Proton 7.77"
 
-    @pytest.mark.usefixtures("verbose_logging")
+    @pytest.mark.usefixtures("info_logging")
     def test_find_steam_default_proton(
             self, steam_app_factory, steam_dir, default_proton,
             proton_factory, steam_config_path, caplog):
@@ -347,8 +367,53 @@ class TestFindSteamCompatToolApp:
 
         assert proton_app.name == "Proton 4.20"
 
-        record = caplog.records[-2]
-        assert "Using stable version of Proton" in record.message
+        assert any(
+            record for record in caplog.records
+            if "Using stable version of Proton" in record.message
+        )
+
+    @pytest.mark.usefixtures("info_logging")
+    def test_find_steam_steamplay_manifest_app_mapping(
+            self, steam_app_factory, steam_dir, proton_factory,
+            appinfo_app_mapping_factory, steam_config_path, caplog):
+        """
+        Ensure the function returns the Proton version defined in the
+        Steam Play manifest if one is defined
+        """
+        steam_app = steam_app_factory(name="Fake game", appid=10)
+        proton_app = proton_factory(
+            name="Test Proton", appid=123450, compat_tool_name="test-proton"
+        )
+
+        appinfo_app_mapping_factory(
+            steam_app=steam_app, compat_tool_name="test-proton"
+        )
+
+        steam_config_path.write_text(
+            vdf.dumps({
+                "InstallConfigStore": {
+                    "Software": {
+                        "Valve": {
+                            "Steam": {}
+                        }
+                    }
+                }
+            })
+        )
+
+        proton_app = find_steam_compat_tool_app(
+            steam_path=steam_dir,
+            steam_apps=[steam_app, proton_app],
+            appid=10
+        )
+
+        assert proton_app.appid == 123450
+
+        assert any(
+            record for record in caplog.records
+            if "App has default compatibility tool mapping in the Steam Play"
+            in record.message
+        )
 
 
 class TestFindLibraryPaths:
@@ -676,16 +741,25 @@ class TestGetSteamApps:
             "Tool manifest for Custom Proton is empty"
         )
 
+    @pytest.mark.parametrize(
+        "content,error",
+        [
+            (b"corrupted", " is corrupted. "),
+            (b"", " is empty. "),  # Regression test for #241
+            (b"\"incompatibilitytools\"\n{\n}", " is incomplete. ")
+        ]
+    )
     def test_get_steam_apps_custom_proton_corrupted_compatibilitytool(
-            self, custom_proton_factory, steam_dir, steam_root, caplog):
+            self, custom_proton_factory, steam_dir, steam_root, caplog,
+            content, error):
         """
         Create a custom Proton installation with a corrupted
         compatibilitytool.vdf and ensure a warning is printed and the app
         is ignored
         """
         custom_proton = custom_proton_factory(name="Custom Proton")
-        (custom_proton.install_path / "compatibilitytool.vdf").write_text(
-            "corrupted"
+        (custom_proton.install_path / "compatibilitytool.vdf").write_bytes(
+            content
         )
 
         steam_apps = get_steam_apps(
@@ -709,9 +783,7 @@ class TestGetSteamApps:
             if record.levelname == "WARNING"
         )
 
-        assert record.getMessage().startswith(
-            "Compatibility tool declaration at"
-        )
+        assert error in record.getMessage()
 
     def test_get_steam_apps_in_library_folder(
             self, default_proton, steam_library_factory, steam_app_factory,
@@ -930,7 +1002,27 @@ class TestGetWindowsShortcuts:
         assert shortcut_apps[0].name == "Non-Steam shortcut: fakegame.exe"
         assert shortcut_apps[0].appid == 4149337689
 
-    @pytest.mark.usefixtures("verbose_logging")
+    def test_get_custom_windows_shortcuts_populate_icon_path(
+            self, steam_dir, shortcut_factory):
+        """
+        Retrieve custom Windows shortcut. The 'icon_path' property is populated
+        if the icon path is found in `shortcuts.vdf`.
+        """
+        shortcut_factory(
+            install_dir="fake/path/", name="fakegame.exe",
+            icon_path="/fake/icon/path.png"
+        )
+
+        shortcut_apps = get_custom_windows_shortcuts(
+            steam_dir, steam_lib_paths=[steam_dir]
+        )
+
+        assert len(shortcut_apps) == 1
+        assert shortcut_apps[0].name == "Non-Steam shortcut: fakegame.exe"
+        assert shortcut_apps[0].appid == 4149337689
+        assert shortcut_apps[0].icon_path == Path("/fake/icon/path.png")
+
+    @pytest.mark.usefixtures("info_logging")
     def test_get_custom_windows_shortcuts_non_numeric_appid(
             self, steam_dir, shortcut_factory, caplog):
         """
@@ -966,7 +1058,7 @@ class TestGetWindowsShortcuts:
             "app ID 'lutris-fake-game'" in record.message
         )
 
-    @pytest.mark.usefixtures("verbose_logging")
+    @pytest.mark.usefixtures("info_logging")
     def test_get_custom_windows_shortcuts_no_prefix(
             self, steam_dir, shortcut_factory, caplog):
         """
